
import 'package:flutter/material.dart';

import 'package:easy_localization/easy_localization.dart' hide TextDirection;

class LanguageTools {

  //------------------------------------------------------------------------ translation

  static const String _default = "en";

  static const enLocal =  Locale('en', 'US');
  static const arLocal =  Locale('ar', 'EG');
  static const defaultLocal = enLocal;

  static const listLocal = [
    enLocal,
    arLocal
  ];


  static bool isArabic(BuildContext context) {
    String name =  context.locale.toString();
    if ( _isEmpty( name ) ) {
      name = _default;
    }
   // Log.i( "language - current: " + name );
    return name == "ar";
  }

  static bool isEnglish(BuildContext context) {
    return !isArabic( context );
  }

  static String getLocalLanguage(BuildContext context){
    String name =  context.locale.toString();
    if ( _isEmpty( name ) ) {
      name = _default;
    }
    return name;
  }

  static setArabic(BuildContext context) {
    context.setLocale (  arLocal ) ; //Locale( "ar");
  }

  static setEnglish( BuildContext context ) {

    context.setLocale ( enLocal);// Locale( "en");
  }

  static setAnyLanguage(BuildContext context, Locale locale ) {
    context.setLocale (   locale) ;
  }

  static TextDirection getTextDirection(BuildContext context){
    if ( isArabic(context) ) {
      return TextDirection.rtl;
    } else {
      return TextDirection.ltr;
    }


  }


  //-----------

  static bool _isEmpty(String? str)
  {
    return !_checkHaveValue(str);
  }

  static bool _checkHaveValue(String? str)
  {
    if (str == null) {
      return false;
    }
    if (str.length == 0) {
      return false;
    }
    if (str == "") {
      return false;
    }
    if (str == "null") {
      return false;
    }
    if ("null" == str.trim().toLowerCase()) {
      return false;
    }
    if (str == " ") {
      return false;
    }
    return true;
  }



}